@@ -41,13 +41,19 @@ test_that("knit_print works with skim summaries", {
 })
 
 test_that("knit_print appropriately falls back to tibble printing", {
-  skip("Temporary skip due to changes in tibble printing")
   skimmed <- skim(iris)
   reduced <- dplyr::select(skimmed, skim_variable, numeric.mean)
-  expect_known_output(
-    input <- knitr::knit_print(reduced),
-    "print/knit_print-fallback.txt"
-  )
+  if (packageVersion("dplyr") <= "0.8.5") {
+    expect_known_output(
+      input <- knitr::knit_print(reduced),
+      "print/knit_print-fallback.txt"
+    )
+  } else {
+    expect_known_output(
+      input <- knitr::knit_print(reduced),
+      "print/knit_print-fallback-dplyrv1.txt"
+    )
+  }
   expect_is(input, "data.frame")
 })
 
@@ -83,7 +89,11 @@ test_that("make_utf8 produces the correct result ", {
 test_that("Skim falls back to tibble::print.tbl() appropriately", {
   input <- skim(iris)
   mean_only <- dplyr::select(input, numeric.mean)
-  expect_print_matches_file(mean_only, "print/fallback.txt")
+  if (packageVersion("dplyr") <= "0.8.5") {
+    expect_print_matches_file(mean_only, "print/fallback.txt")
+  } else {
+    expect_print_matches_file(mean_only, "print/fallback_dplyrv1.txt")
+  }
 })
 
 test_that("Print focused objects appropriately", {
